<?php
/**
 * DZF
 *
 * LICENSE: Redistribution and use in source and binary forms, with or without
 * modifications, are not permitted.
 *
 * @copyright Deubert IT-Solutions © 2012-2014 All rights reserved
 * @package DZF
 */

#namespace DeubertIt;

/**
 * @author Karsten Deubert <info@deubert.it>
 */
class DZF_Doctrine_Helper
{
    /**
     * @param string $model
     * @param string $column
     * @return array|bool
     */
    public static function getModelColumnData($model, $column)
    {
        /** @var \Doctrine_Record $dummy */
        $dummy = new $model;
        $columns = $dummy->getTable()->getColumns();
        unset($dummy);

        return array_key_exists($column, $columns) ? $columns[$column] : false;
    }

    public static function getLayoutConfig($modelNames)
    {
        $layoutConfig = array();

        foreach ($modelNames as $modelKey)
        {
            $configData = array();

            if (method_exists($modelKey, 'getLayoutConfig'))
            {
                $configData = call_user_func(array($modelKey, 'getLayoutConfig'));
            }

            $layoutConfig[$modelKey] = $configData;
        }

        return $layoutConfig;
    }

    public static function getModelPrimaryKeys($model)
    {
        /** @var \Doctrine_Record $dummy */
        $dummy = new $model;
        $columns = $dummy->getTable()->getIdentifierColumnNames();
        unset($dummy);

        return $columns;
    }

    public static function getModelRelations($model)
    {
        /** @var \Doctrine_Record $dummy */
        $dummy = new $model;
        $relations = $dummy->getTable()->getRelationParser()->getRelations();
        unset($dummy);

        return $relations;
    }

    public static function getObjectTypeFromRelationName($parentName, $modelName, $relationName)
    {
        // 1:n
        if (is_numeric($relationName))
        {
            $newModelName = $modelName;
        }
        // 1:1
        else
        {
            $modelRelations = self::getModelRelations($modelName);

            if (array_key_exists($relationName, $modelRelations))
            {
                $newModelName = $modelRelations[$relationName]->getClass();
            }
            else
            {
                throw new DZF_Exception('relation class not found: '.$modelName.'->'.$relationName);
            }
        }

        return $newModelName;
    }

    public static function getPrimaryKeys($config, $record)
    {
        $primaryKeys = array();

        foreach ($config as $key)
        {
            $primaryKeys[$key] = $record[$key];
        }

        return $primaryKeys;
    }

    public static function updateFromPostValues(\Doctrine_Record &$model, $formData)
    {
        $modelClass = get_class($model);
        foreach ($formData as $formKey => $formValue)
        {
            if (strpos($formKey, $modelClass.'--') !== false)
            {
                $modelField = str_replace($modelClass.'--', '', $formKey);

                $modelColumnData = self::getModelColumnData($modelClass, $modelField);

                if (array_key_exists('notnull', $modelColumnData) && !$modelColumnData['notnull'])
                {
                    if ($formValue == '')
                    {
                        $formValue = null;
                    }
                }

                $model->set($modelField, $formValue);
            }
        }
    }
}