<?php
/**
 * DZF
 *
 * LICENSE: Redistribution and use in source and binary forms, with or without
 * modifications, are not permitted.
 *
 * @copyright Deubert IT-Solutions © 2012-2014 All rights reserved
 * @package DZF
 */

#namespace DeubertIt;

/**
 * @author Karsten Deubert <info@deubert.it>
 */
class DZF_Http_Client extends \Zend_Http_Client
{
    public static $fullDebugLoggingActive = false;
    public static $fullDebugLoggingCustomPath = null;

    /**
     * Send the HTTP request and return an HTTP response object
     *
     * @param string $method
     * @return \Zend_Http_Response
     * @throws \Zend_Http_Client_Exception
     */
    public function request($method = null)
    {
        try
        {
            $response = parent::request($method);

            if (self::$fullDebugLoggingActive)
            {
                $this->fullDebugLog($response, $method);
            }
        }
        catch (\Zend_Http_Client_Exception $exception)
        {
            if (self::$fullDebugLoggingActive)
            {
                $this->fullDebugExceptionLog($exception, $method);
            }

            // rethrow to not change behaviour
            throw $exception;
        }

        return $response;
    }

    /**
     * @param bool $flag
     */
    public static function setFullDebugLoggingActive($flag)
    {
        self::$fullDebugLoggingActive = $flag;
    }

    /**
     * @param string $path
     */
    public static function setFullDebugLoggingCustomPath($path)
    {
        self::$fullDebugLoggingCustomPath = $path;
    }

    /**
     * @param \Zend_Http_Response $response
     * @param $method
     */
    public function fullDebugLog($response, $method)
    {
        $now = time();
        $microNow = microtime();
        $microData = explode(' ', $microNow);
        $random = mt_rand(100000, 999999);

        $logPath = !is_null(self::$fullDebugLoggingCustomPath)
            ? self::$fullDebugLoggingCustomPath
            : LOG_PATH.'/dzf-http-debuglogs';

        $path = $logPath.'/'.date('Y-m-d', $now).'/'.date('H', $now).'/';
        if (!file_exists($path)) {
            mkdir($path, 0755, true);
        }

        $requestTimeString = ($_SERVER && is_array($_SERVER) && array_key_exists('REQUEST_TIME_FLOAT', $_SERVER))
            ? $_SERVER['REQUEST_TIME_FLOAT']
            : $now.'.'.$microData[0];

        $name = 'default';

        $uri = $this->getUri();
        $hostString = $uri->getHost();
        $pathString = str_replace('/', '--', $uri->getPath());

        $fileName = date('Y-m-d_H-i-s', $now).'_'.$requestTimeString.'_'.$hostString.'_'.$pathString.'_'.$random.'_'.$name.'.php';

        $request = $this->getLastRequest();

        $fileContent = "<?php\n\n";
        $fileContent .= "/*\n";
        $fileContent .= ' * Date: ' . date('d.m.Y H:i:s', $now) . "\n";
        $fileContent .= ' * File: ' . $fileName . "\n";
        $fileContent .= ' * Name: ' . $name . "\n";
        $fileContent .= ' * Uri: ' . $this->getUri(true) . "\n";
        $fileContent .= " */\n\n";
        $fileContent .= "/*\n";
        $fileContent .= '$request = ' . str_replace('*/', '*//*', var_export($request, true)) . ';';
        $fileContent .= "\n\n";
        $fileContent .= '$method = ' . var_export($method, true) . ';';
        $fileContent .= "\n\n";
        $fileContent .= '$response = ' . str_replace('*/', '*//*', var_export($response, true)) . ';';
        $fileContent .= "\n\n";
        $fileContent .= '$body = ' . str_replace('*/', '*//*', var_export($response->getBody(), true)) . ';';
        $fileContent .= "\n\n";
        $fileContent .= '$_REQUEST: '.var_export($_REQUEST, true)."\n\n";
        $fileContent .= '$_GET: '.var_export($_GET, true)."\n\n";
        $fileContent .= '$_POST: '.var_export($_POST, true)."\n\n";
        $fileContent .= '$_SERVER: '.str_replace('*/', '*//*', var_export($_SERVER, true))."\n\n";
        $fileContent .= '$_COOKIE: '.var_export($_COOKIE, true)."\n\n";
        $fileContent .= '$_SESSION: '.var_export($_SESSION, true)."\n\n";
        $fileContent .= "\n*/\n";
        $fileContent .= "\n\n";
        $responseString = base64_encode(serialize($response));
        $fileContent .= '$response = \'' . $responseString . '\';';
        $fileContent .= "\n\n";
        $fileContent .= '$body = \'' . serialize($response->getBody()) . '\';';

        file_put_contents($path.$fileName, $fileContent);
    }

    /**
     * @param \Exception $exception
     * @param $method
     */
    public function fullDebugExceptionLog($exception, $method)
    {
        $now = time();
        $microNow = microtime();
        $microData = explode(' ', $microNow);
        $random = mt_rand(100000, 999999);

        $logPath = !is_null(self::$fullDebugLoggingCustomPath)
            ? self::$fullDebugLoggingCustomPath
            : LOG_PATH.'/dzf-http-debuglogs';

        $path = $logPath.'/'.date('Y-m-d', $now).'/'.date('H', $now).'/';
        if (!file_exists($path)) {
            mkdir($path, 0755, true);
        }

        $requestTimeString = ($_SERVER && is_array($_SERVER) && array_key_exists('REQUEST_TIME_FLOAT', $_SERVER))
            ? $_SERVER['REQUEST_TIME_FLOAT']
            : $now.'.'.$microData[0];

        $name = 'exception';

        $uri = $this->getUri();
        $hostString = $uri->getHost();
        $pathString = str_replace('/', '--', $uri->getPath());

        $fileName = date('Y-m-d_H-i-s', $now).'_'.$requestTimeString.'_'.$hostString.'_'.$pathString.'_'.$random.'_'.$name.'.php';

        $request = $this->getLastRequest();

        $fileContent = "<?php\n\n";
        $fileContent .= "/*\n";
        $fileContent .= ' * Date: ' . date('d.m.Y H:i:s', $now) . "\n";
        $fileContent .= ' * File: ' . $fileName . "\n";
        $fileContent .= ' * Name: ' . $name . "\n";
        $fileContent .= ' * Uri: ' . $this->getUri(true) . "\n";
        $fileContent .= " */\n\n";
        $fileContent .= "/*\n";
        $fileContent .= '$request = ' . str_replace('*/', '*//*', var_export($request, true)) . ';';
        $fileContent .= "\n\n";
        $fileContent .= '$method = ' . var_export($method, true) . ';';
        $fileContent .= "\n\n";
        $fileContent .= '$exception = ' . print_r($exception, true) . ';';
        $fileContent .= "\n\n";
        $fileContent .= '$_REQUEST: '.var_export($_REQUEST, true)."\n\n";
        $fileContent .= '$_GET: '.var_export($_GET, true)."\n\n";
        $fileContent .= '$_POST: '.var_export($_POST, true)."\n\n";
        $fileContent .= '$_SERVER: '.str_replace('*/', '*//*', var_export($_SERVER, true))."\n\n";
        $fileContent .= '$_COOKIE: '.var_export($_COOKIE, true)."\n\n";
        $fileContent .= '$_SESSION: '.var_export($_SESSION, true)."\n\n";
        $fileContent .= "\n*/\n";
        $fileContent .= "\n\n";
        $fileContent .= '$exception = \'' . serialize($exception) . '\';';

        file_put_contents($path.$fileName, $fileContent);
    }
}