<?php
/**
 * DZF
 *
 * LICENSE: Redistribution and use in source and binary forms, with or without
 * modifications, are not permitted.
 *
 * @copyright Deubert IT-Solutions © 2012-2014 All rights reserved
 * @package DZF
 */

#namespace DeubertIt;

/**
 * @author Karsten Deubert <info@deubert.it>
 */
class DZF_JobRunner
{
    protected $jobs;
    protected $jobName;
    protected $logger;

    public function __construct($jobs, $jobName)
    {
        $this->jobs = $jobs;
        $this->jobName = $jobName;

        $this->logger = \Zend_Registry::get('logger');
    }

    public function execute()
    {
        $myPid = getmypid();

        $requestTime = time();

        $logPrefix = 'jobrunner-'.$this->jobName.'-'.$myPid;

        $startLoopTime = (microtime(true)-$requestTime)*1000;
        $this->getLogger()->log($logPrefix.' start', \Zend_Log::INFO);

        $i = 0;

        foreach ($this->jobs as $job)
        {
            $this->getLogger()->log($logPrefix.' '.$i.' starting job execution: '.$job['service'].'::'.$job['method'], \Zend_Log::INFO);

            $startTime = (microtime(true)-$requestTime)*1000;

            try
            {
                $service = new $job['service'];
                $service->{$job['method']}();
            }
            catch (\Exception $e)
            {
                $this->getLogger()->log($logPrefix.' '.$i.' job execution exception '.get_class($e).': '.$e->getMessage()."\n".$e->getTraceAsString(), \Zend_Log::ERR);
            }

            $stopTime = (microtime(true)-$requestTime)*1000;
            $runningTime = $stopTime - $startTime;

            $this->getLogger()->log($logPrefix.' '.$i.' job execution time: '.$runningTime, \Zend_Log::INFO);
        }

        $stopLoopTime = (microtime(true)-$requestTime)*1000;
        $runningLoopTime = $stopLoopTime - $startLoopTime;

        $this->getLogger()->log($logPrefix.' completed: '.$runningLoopTime, \Zend_Log::INFO);
    }

    /**
     * @return \Zend_Log
     */
    public function getLogger()
    {
        return $this->logger;
    }
}
