<?php
/**
 * DZF
 *
 * LICENSE: Redistribution and use in source and binary forms, with or without
 * modifications, are not permitted.
 *
 * @copyright Deubert IT-Solutions © 2012-2014 All rights reserved
 * @package DZF
 */

#namespace DeubertIt;

/**
 * To enable versioning just do the following steps:
 * 1) add row 
 *           use DZF_Model_Trait_Versions;
 *                                          to the base class of your class declaration
 * 1.1)add row 
 *              $this->_setUpVersions(); 
 *                                          to the public function setUp() of your base model
 * 3) add migration child of DZF_Doctrine_Migration_Versionize with protected variable $_modelName = "CLASSNAME"; 
 * 
 *
 * !!!IMPORTANT NOTE: fields like "flat_*" WILL NOT TRIGGER VERSION SAVE
 * @author Rostislav Boiko <r.boyko@luckywarepro.com>
 */
trait DZF_Model_Trait_Versions {

    public function getVersions($max_count = 10) {
        $objects = \Doctrine_Query::create()
                ->from($this->_getOwnVersionClass())
                ->where('id = ?', $this->get('id'))
                ->orderBy('version DESC')
                ->limit((int) $max_count)
                ->execute();
        return $objects;
    }

    public function getVersion($verNum = 1) {
        $records = \Doctrine::getTable($this->_getOwnVersionClass())
                ->findBySql('id = ? and version = ?', array($this->get('id'), (int) $verNum));
        return $records[0];
    }

    protected function _getOwnVersionClass() {
        return get_class($this) . 'Version';
    }

    public function createInitialVersion() {
        if ($this->get('version') == 0) {
            $class = $this->_getOwnVersionClass();
            $this->set('version', 1);
            $version = new $class();
            $version->merge($this->toArray(), false);
            $version->save();
            $this->save();
        }
    }

    protected function _getActClass(){
        return "%CLASS%";
    }

    protected function _setUpVersions() {
        $this->actAs('Versionable', array(
            'versionColumn' => 'version',
            'className' => $this->_getActClass() . 'Version',
            'auditLog' => true,
            'listener' => 'DZF_AuditLog_Listener'
                )
        );
    }

    /**
     * revert
     * reverts this record to given version, this method only works if versioning plugin
     * is enabled
     *
     * @throws DZF_Exception    if given version does not exist
     * @param integer $version      an integer > 1
     * @return Doctrine_Record      this object
     */
    public function revert($version)
    {
        $auditLog = $this->getAuditLog();

        if ( ! $auditLog->getOption('auditLog')) {
            throw new DZF_Exception('Audit log is turned off, no version history is recorded.');
        }

        $data = $auditLog->getVersion($this->getInvoker(), $version);

        if ( ! isset($data[0])) {
            throw new DZF_Exception('Version ' . $version . ' does not exist!');
        }

        $this->getInvoker()->merge($data[0]);

        // Prevent creating a new version
        $auditLog->setOption('auditLog', false);

        return $this->getInvoker();
    }
}
