<?php
/**
 * DZF
 *
 * LICENSE: Redistribution and use in source and binary forms, with or without
 * modifications, are not permitted.
 *
 * @copyright Deubert IT-Solutions © 2012-2014 All rights reserved
 * @package DZF
 */

#namespace DeubertIt;

/**
 * @author Karsten Deubert <info@deubert.it>
 */
class DZF_Pager_LayoutSA extends \Doctrine_Pager_Layout
{
    public function display($options = array(), $return = false)
    {
        $pager = $this->getPager();

        $currentPage = $pager->getPage();
        $firstPage = $pager->getFirstPage();
        $previousPage = $pager->getPreviousPage();
        $nextPage = $pager->getNextPage();
        $lastPage = $pager->getLastPage();

        $this->setTemplate('<li><a href="{%url}">{%page}</a></li>');
        $this->setSelectedTemplate('<li class="active"><a href="{%url}">{%page}</a></li>');

        $str  = '<div class="browsing">';

        $str .= '<ul class="pagination">';

        $this->addMaskReplacement('page', '<i class="fa fa-fast-backward"></i>', true);
        $options['page_number'] = $firstPage;
        $options['liclass'] = '';
        if ($currentPage <= $firstPage)
        {
            $options['liclass'] .= ' disabled';
        }
        $options['noselected'] = true;
        $str .= $this->processPage($options);

        $this->addMaskReplacement('page', '<i class="glyphicon glyphicon-arrow-left"></i>', true);
        $options['page_number'] = $previousPage;
        $options['liclass'] = 'prev';
        if ($currentPage <= $previousPage)
        {
            $options['liclass'] .= ' disabled';
        }
        $options['noselected'] = true;
        $str .= $this->processPage($options);

        $this->removeMaskReplacement('page');
        $options['liclass'] = '';
        $options['noselected'] = false;
        $str .= parent::display($options, true);

        $this->addMaskReplacement('page', '<i class="glyphicon glyphicon-arrow-right"></i>', true);
        $options['page_number'] = $nextPage;
        $options['liclass'] = 'next';
        if ($currentPage >= $nextPage)
        {
            $options['liclass'] .= ' disabled';
        }
        $options['noselected'] = true;
        $str .= $this->processPage($options);

        $this->addMaskReplacement('page', '<i class="fa fa-fast-forward"></i>', true);
        $options['page_number'] = $lastPage;
        $options['liclass'] = '';
        if ($currentPage >= $lastPage)
        {
            $options['liclass'] .= ' disabled';
        }
        $options['noselected'] = true;
        $str .= $this->processPage($options);

        $str .= '</ul>';

        if($return)
        {
            return $str;
        }

        echo $str;
    }

    /**
     * _parseUrlTemplate
     *
     * Parse the url mask to return the correct template depending of the options sent.
     * Already process the mask replacements assigned.
     *
     * @param array $options    Optional parameters to be applied in template and url mask
     * @return string
     */
    protected function _parseUrlTemplate($options = array())
    {
        $str = '';

        // If given page is the current active one
        if ($options['page_number'] == $this->getPager()->getPage() && (!array_key_exists('noselected', $options) || !$options['noselected'])) {
            $str = $this->_parseMaskReplacements($this->getSelectedTemplate());
        }

        // Possible attempt where Selected == Template
        if ($str == '') {
            $str = $this->_parseMaskReplacements($this->getTemplate());
        }

        return $str;
    }

    /**
     * _parseTemplate
     *
     * Parse the template of a given page and return the processed template
     *
     * @param array    Optional parameters to be applied in template and url mask
     * @return string
     */
    protected function _parseTemplate($options = array())
    {
        $str = $this->_parseUrlTemplate($options);
        $replacements = $this->_parseReplacementsTemplate($options);

        $replacedStr = strtr($str, $replacements);

        if (array_key_exists('liclass', $options) && $options['liclass'] != '')
        {
            $replacedStr = str_replace('<li>', '<li class="'.$options['liclass'].'">', $replacedStr);
        }

        return $replacedStr;
    }
}