<?php
/**
 * DZF
 *
 * LICENSE: Redistribution and use in source and binary forms, with or without
 * modifications, are not permitted.
 *
 * @copyright Deubert IT-Solutions © 2017 All rights reserved
 * @package DZF
 */

#namespace DeubertIt;

/**
 * @author Eugene Melnik <e.melnik@luckywarepro.com>
 */
class DZF_Settings_Source_Ini extends DZF_Settings_Source
{
    /**
     * @var array
     */
    protected $_config;

    /**
     * @param   string|array        $configFilePath
     * @param   string              $section
     * @param   array               $options
     * @throws DZF_Exception
     */
    public function __construct($configFilePath, $section = null, $options = false)
    {
        if (is_string($configFilePath))
        {
            $iniConfig = new \Zend_Config_Ini($configFilePath, $section, $options);
            $config = $iniConfig->toArray();
        }
        else if (is_array($configFilePath))
        {
            $config = [];

            foreach ($configFilePath as $configPath)
            {
                $iniConfig = new \Zend_Config_Ini($configPath, $section, $options);
                $config = array_replace_recursive($config, $iniConfig->toArray());
            }
        }
        else
        {
            throw new DZF_Exception('Should be a string or array of strings');
        }

        $this->_config = $config;
    }

    /**
     * @param   string          $groupKey
     * @param   string          $paramName      (optional)
     * @return  mixed|null
     */
    public function getValue($groupKey, $paramName = null)
    {
        if (is_array($this->_config) && !empty($this->_config) && isset($this->_config[$groupKey]))
        {
            if (is_null($paramName))
            {
                return $this->_config[$groupKey];
            }

            if (is_array($this->_config[$groupKey]) && array_key_exists($paramName, $this->_config[$groupKey]))
            {
                return $this->_config[$groupKey][$paramName];
            }
        }

        return null;
    }
}
