<?php
/**
 * DZF
 *
 * LICENSE: Redistribution and use in source and binary forms, with or without
 * modifications, are not permitted.
 *
 * @copyright Deubert IT-Solutions © 2012-2014 All rights reserved
 * @package DZF
 */

#namespace DeubertIt;

/**
 * @author Karsten Deubert <info@deubert.it>
 */
class DZF_View_Helper_RelativeTime extends \Zend_View_Helper_Abstract
{
    /**
     * @param int $time unix timestamp
     * @param null $now unix timestamp, defaults to time()
     * @return string
     */
    public function relativeTime($time, $now = null)
    {
        if (is_null($now))
        {
            $now = time();
        }

        $translate = \Zend_Registry::get('Zend_Translate');

        $difference = $now - $time;

        $minute = 60;
        $hour = $minute * 60;
        $day = $hour * 24;
        $month = $day * 30;
        $year = $day * 365;

        if ($difference >= $year)
        {
            $years = ((int)floor($difference / $year));
            if ($years > 1)
            {
                return sprintf($translate->translate('vor %d Jahren'), $years);
            }
            else
            {
                return $translate->translate('vor einem Jahr');
            }
        }
        elseif ($difference >= $month)
        {
            $months = ((int)floor($difference / $month));
            if ($months > 1)
            {
                return sprintf($translate->translate('vor %d Monaten'), $months);
            }
            else
            {
                return $translate->translate('vor einem Monat');
            }
        }
        elseif ($difference >= $day)
        {
            $days = ((int)floor($difference / $day));
            if ($days > 1)
            {
                return sprintf($translate->translate('vor %d Tagen'), $days);
            }
            else
            {
                return $translate->translate('gestern');
            }
        }
        elseif ($difference >= $hour)
        {
            $hours = ((int)floor($difference / $hour));
            if ($hours > 1)
            {
                return sprintf($translate->translate('vor %d Stunden'), $hours);
            }
            else
            {
                return $translate->translate('vor einer Stunde');
            }
        }
        elseif ($difference >= $minute)
        {
            $minutes = ((int)floor($difference / $minute));
            if ($minutes > 1)
            {
                return sprintf($translate->translate('vor %d Minuten'), $minutes);
            }
            else
            {
                return $translate->translate('vor einer Minute');
            }
        }
        else
        {
            return $translate->translate('gerade eben');
        }
    }
}