<?php

class ZFDebugTests extends DZF_Helpers_TestCaseBase
{
    public function testZFDebug()
    {
        $options = array(
            'plugins' => array('Variables',
                    'File' => array('basePath' => '/path/to/project'),
                    'Cache' => array('backend' => ['a' => 1]),
                )
        );

        $zendConfig = new Zend_Config($options);

        $pluginDebug = new ZFDebug_Controller_Plugin_Debug($zendConfig);


        $ZFDebug = new DZF_Log_Writer_ZFDebug($pluginDebug);

        $this->assertNotNull($ZFDebug);
    }

    /**
     * @expectedException Zend_Log_Exception
     * @expectedExceptionMessage Plugin must be an instance of ZFDebug_Controller_Plugin_Debug
     */
    public function testException()
    {
        $options = array(
            'plugins' => array('Variables',
                'Database' => array('adapter' => 'sqlite'),
                'File' => array('basePath' => '/path/to/project'),
                'Cache' => array('backend' => ['a' => 1]),
                'Exception')
        );

        $ZFDebug = new DZF_Log_Writer_ZFDebug($options);
    }

    public function testZFDebugWrite()
    {
        $options = array(
            'plugins' => array('Variables',
                'File' => array('basePath' => '/path/to/project'),
                'Cache' => array('backend' => ['a' => 1]),
            ),
            'message' => 'new Message'
        );

        $zendConfig = new Zend_Config($options);

        $pluginDebug = new ZFDebug_Controller_Plugin_Debug($zendConfig);

        $ZFDebug = new DZF_Log_Writer_ZFDebug($pluginDebug);

        $ZFDebug->write($options);

        $this->assertNotNull($ZFDebug);
    }

    public function testZFDebugWriteEventInfoTabName()
    {
        $options = array(
            'plugins' => array('Variables',
                'File' => array('basePath' => '/path/to/project'),
                'Cache' => array('backend' => ['a' => 1]),
            ),
            'message' => 'new Message',
            'tabName' => 'tab Name'
        );

        $zendConfig = new Zend_Config($options);

        $pluginDebug = new ZFDebug_Controller_Plugin_Debug($zendConfig);

        $ZFDebug = new DZF_Log_Writer_ZFDebug($pluginDebug);

        $ZFDebug->write($options);

        $this->assertNotNull($ZFDebug);
    }

    public function testZFDebugWriteEventInfoArray()
    {
        $options = array(
            'plugins' => array('Variables',
                'File' => array('basePath' => '/path/to/project'),
                'Cache' => array('backend' => ['a' => 1]),
            ),
            'message' => 'new Message',
            'info' => ['info1', 'info2']
        );

        $zendConfig = new Zend_Config($options);

        $pluginDebug = new ZFDebug_Controller_Plugin_Debug($zendConfig);

        $ZFDebug = new DZF_Log_Writer_ZFDebug($pluginDebug);

        $ZFDebug->write($options);

        $this->assertNotNull($ZFDebug);
    }

    public function testZFDebugWriteEventInfoString()
    {
        $options = array(
            'plugins' => array('Variables',
                'File' => array('basePath' => '/path/to/project'),
                'Cache' => array('backend' => ['a' => 1]),
            ),
            'message' => 'new Message',
            'info' => 'info string'
        );

        $zendConfig = new Zend_Config($options);

        $pluginDebug = new ZFDebug_Controller_Plugin_Debug($zendConfig);

        $ZFDebug = new DZF_Log_Writer_ZFDebug($pluginDebug);

        $ZFDebug->write($options);

        $this->assertNotNull($ZFDebug);
    }

    public function testZFDebugWriteEmptyTab()
    {
        $options = array(
            'plugins' => array('Variables',
                'File' => array('basePath' => '/path/to/project'),
                'Cache' => array('backend' => ['a' => 1]),
            ),
            'message' => 'new Message'
        );

        $zendConfig = new Zend_Config($options);

        $pluginDebug = new ZFDebug_Controller_Plugin_Debug($zendConfig);

        $ZFDebug = new DZF_Log_Writer_ZFDebug($pluginDebug, FALSE);

        $ZFDebug->write($options);

        $this->assertNotNull($ZFDebug);
    }

    /**
     * @expectedException Zend_Exception
     * @expectedExceptionMessage DZF_Log_Writer_ZFDebug does not currently implement a factory
     */
    public function testFactoryException()
    {
        $options = array(
            'plugins' => array('Variables',
                'Database' => array('adapter' => 'sqlite'),
                'File' => array('basePath' => '/path/to/project'),
                'Cache' => array('backend' => ['a' => 1]),
                'Exception')
        );

        DZF_Log_Writer_ZFDebug::factory($options);
    }
}
